@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Getopt::Long with Class - ~/lib/Getopt/Class.pm
-## Version v0.103.0
+## Version v0.103.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/04/25
-## Modified 2022/10/23
+## Modified 2022/10/24
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -26,7 +26,7 @@ BEGIN
     use Module::Generic::Scalar;
     use Nice::Try;
     use Scalar::Util;
-    our $VERSION = 'v0.103.0';
+    our $VERSION = 'v0.103.1';
 };
 
 use strict;
@@ -467,7 +467,7 @@ sub postprocess
         
         if( ( $def->{type} eq 'date' || $def->{type} eq 'datetime' ) && length( $opts->{ $k } ) )
         {
-            my $tz;
+            my( $dt, $tz );
             # DateTime::TimeZone::Local will die ungracefully if the local timezeon is not set with the error:
             # "Cannot determine local time zone"
             try
@@ -485,8 +485,7 @@ sub postprocess
             {
                 try
                 {
-                    my $dt = DateTime->from_epoch( epoch => $opts->{ $k } );
-                    $opts->{ $k } = $dt;
+                    $dt = DateTime->from_epoch( epoch => $opts->{ $k } );
                 }
                 catch( $e )
                 {
@@ -497,7 +496,7 @@ sub postprocess
             {
                 try
                 {
-                    my $dt = DateTime->new(
+                    $dt = DateTime->new(
                         year => int( $+{year} ),
                         month => int( $+{month} ),
                         day => int( $+{day} ),
@@ -506,7 +505,6 @@ sub postprocess
                         second => 0,
                         time_zone => $tz,
                     );
-                    $opts->{ $k } = $dt;
                 }
                 catch( $e )
                 {
@@ -517,7 +515,7 @@ sub postprocess
             {
                 try
                 {
-                    my $dt = DateTime->new(
+                    $dt = DateTime->new(
                         year => int( $+{year} ),
                         month => int( $+{month} ),
                         day => int( $+{day} ),
@@ -526,7 +524,6 @@ sub postprocess
                         second => int( $+{second} ),
                         time_zone => 'local',
                     );
-                    $opts->{ $k } = $dt;
                 }
                 catch( $e )
                 {
@@ -535,8 +532,7 @@ sub postprocess
             }
             elsif( $opts->{ $k } eq 'now' || $opts->{ $k } eq 'today' )
             {
-                my $dt = DateTime->now( time_zone => $tz );
-                $opts->{ $k } = $dt;
+                $dt = DateTime->now( time_zone => $tz );
             }
             else
             {
@@ -548,7 +544,8 @@ sub postprocess
                 locale => 'en_GB',
                 time_zone => $tz,
             );
-            $opts->{ $k }->set_formatter( $fmt );
+            $dt->set_formatter( $fmt );
+            $opts->{ $k } = $dt;
         }
         elsif( $def->{type} eq 'array' )
         {
@@ -1091,7 +1088,7 @@ Getopt::Class - Extended dictionary version of Getopt::Long
 
 =head1 VERSION
 
-    v0.103.0
+    v0.103.1
 
 =head1 DESCRIPTION
 
